@@ -2,7 +2,7 @@ package Net::DNS::RR::OPT;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: OPT.pm 1921 2023-05-08 18:39:59Z willem $)[2];
+our $VERSION = (qw$Id: OPT.pm 1934 2023-08-25 12:14:08Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -79,12 +79,6 @@ sub class {				## override RR method
 	return $self->udpsize(@value);
 }
 
-sub size {
-	my ( $self, @value ) = @_;				# uncoverable pod
-	$self->_deprecate(qq[size() is an alias of "UDPsize()"]);
-	return $self->udpsize(@value);
-}
-
 sub ttl {				## override RR method
 	my ( $self, @value ) = @_;
 	$self->_deprecate(qq[please use "flags()", "rcode()" or "version()"]);
@@ -157,6 +151,12 @@ sub udpsize {
 	return $self->{udpsize} || 0;
 }
 
+sub size {
+	my ( $self, @value ) = @_;				# uncoverable pod
+	$self->_deprecate(qq[size() is an alias of "UDPsize()"]);
+	return $self->udpsize(@value);
+}
+
 
 sub rcode {
 	my ( $self, @value ) = @_;
@@ -442,19 +442,19 @@ sub _decompose {
 	my $error = $Net::DNS::Parameters::dnserrorbyval{$code};
 	my @error = defined($error) ? ( 'ERROR' => $error ) : ();
 	my $extra = Net::DNS::Text->decode( \$text, 0, length $text );
-	my $REGEX = q/("[^"]*")|([\[\]{}:,])|\s+/;
 	for ( $extra->value ) {
 		last unless /^[\[\{]/;
-		s/([\@\$])/\\$1/g;
-		my $info = eval join( ' ', map { s/^:$/=>/; $_ } grep {defined} split /$REGEX/o );
-		return {'INFO-CODE' => $code, @error, 'EXTRA-TEXT' => $info || last};
+		s/([\$\@])/\\$1/g;	## Here be dragons!
+		my $REGEX = q/("[^"]*"|[\[\]{}:,]|[-0-9.Ee+]+)|\s+|(.)/;
+		my @split = grep { defined && length } split /$REGEX/o;
+		my $value = eval join( ' ', 'no integer;', map { s/^:$/=>/; $_ } @split );
+		return {'INFO-CODE' => $code, @error, 'EXTRA-TEXT' => $value} if ref($value);
 	}
-	return {'INFO-CODE' => $code, @error, 'EXTRA-TEXT' => $extra->string};
+	return {'INFO-CODE' => $code, @error, 'EXTRA-TEXT' => $extra->value};
 }
 
 
 package Net::DNS::RR::OPT::REPORT_CHANNEL;			# draft-ietf-dnsop-dns-error-reporting
-$Net::DNS::Parameters::ednsoptionbyval{65023} = 'REPORT-CHANNEL';	## experimental/private use
 
 sub _compose {
 	my ( undef, @argument ) = map { ref($_) ? %$_ : $_ } @_;
